import React, { useState, useEffect } from 'react';
import {
  scaleTime,
  extent,
  scaleLog,
  max,
  min,
  line,
} from 'd3';
import { XAxis } from './XAxis';
import { YAxis } from './YAxis';
const xValue = (d) => d.date;
const yValue = (d) => d.deathTotal;

const margin = {
  left: 100,
  right: 80,
  top: 40,
  bottom: 60,
};
export const LineChart = ({ data, width, height }) => {
  const innerWidth = width - (margin.left + margin.right);
  const innerHeight = height - (margin.top + margin.bottom);

  const xScale = scaleTime()
    .domain(extent(data, xValue))
    .range([0, innerWidth]);

  const yScale = scaleLog()
    .domain([min(data, yValue), max(data, yValue)])
    .range([innerHeight, 0]);

  const lineGenerator = line()
    .x((d) => xScale(xValue(d)))
    .y((d) => yScale(yValue(d)));

  return (
    <svg width={width} height={height}>
      <g
        transform={`translate(${margin.left},${margin.top})`}
      >
        <XAxis xScale={xScale} innerHeight={innerHeight} />
        <YAxis yScale={yScale} innerWidth={innerWidth} />
        <path d={lineGenerator(data)} />
        <text transform={`translate(${innerWidth / 3},0)`}>
          CoronaVirus Global Death{' '}
        </text>
        <text
          text-anchor="middle"
          transform={`translate(-70,${
            innerHeight / 2
          }) rotate(-90)`}
        >
          Comulative Deaths
        </text>
        <text
          alignment-baseline="hanging"
          transform={`translate(${innerWidth / 2},${
            innerHeight + 30
          })`}
        >
          Time
        </text>
      </g>
    </svg>
  );
};
